@@ -6,6 +6,7 @@
 # Disclaimer: pyDARN is licensed under the GPL v 3.0 found in LICENSE
 #
 
+
 def standard_warning_format(message: str, category: str, filename: str,
                             lineno: int, file: str = None,
                             line: int = None) -> str:
@@ -61,7 +62,6 @@ def only_message_warning_format(message: str, category: str, filename: str,
     -------
         formatted warning message to be printed to the console
     """
-    return "{category}: {message}\n".format(filename=filename,
-                                            linenum=lineno,
-                                            category=category.__name__,
-                                            message=message)
+    return "{filename} {linenum} {category}: {message}\n"\
+        "".format(filename=filename, linenum=lineno,
+                  category=category.__name__, message=message)
